@@ -8,8 +8,8 @@ class Model:
 
         movie_rating_predictions = []
         for movie in user_movie_list:
-            predicted_rating = self.model.predict(user_id, movie)
-            movie_rating_predictions.append((movie, predicted_rating))
+            prediction = self.model.predict(user_id, movie)
+            movie_rating_predictions.append((movie, prediction.est))
 
         movie_ranking = sorted(movie_rating_predictions, key = lambda movie_rating_tuple: movie_rating_tuple[1], reverse=True)
         return [movie_rating_tuple[0] for movie_rating_tuple in movie_ranking[:20]]
